@@ -1,6 +1,16 @@
 import click
 from crontab import CronTab
-from automation import root_dir, get_files, main, add_cron_job, every_minute, daily, weekly, hourly, monthly
+from automation import (
+    root_dir,
+    get_files,
+    main,
+    add_cron_job,
+    every_minute,
+    daily,
+    weekly,
+    hourly,
+    monthly
+)
 
 
 @click.group()
